import numpy as np
import matplotlib.pyplot as plt
from matplotlib.ticker import AutoMinorLocator

# Set font parameters
plt.rcParams.update({
    'font.family': 'sans-serif',
    'font.sans-serif': ['DejaVu Sans', 'Helvetica', 'Bitstream Vera Sans', 'Arial', 'sans-serif'],
    'font.size': 10,
    'xtick.labelsize': 10,
    'ytick.labelsize': 10,
    'axes.linewidth': 0.8,
    'xtick.major.width': 1.0,
    'ytick.major.width': 1.0,
    'legend.columnspacing': 0.5,
    'legend.handletextpad': 0.25,
    'legend.borderaxespad': 0.25,
})

# Create the figure
fig, ax1 = plt.subplots(figsize=(4.5, 2.8))

# Second y-axis (right side)
ax2 = ax1.twinx()

# Files with colors and labels
files = [
    ("dtauef_dw_int_-25meV.dat", "−25 meV", "blue"),
    ("dtauef_dw_int_0meV.dat", "   0   meV", "black"),
    ("dtauef_dw_int_25meV.dat", "+25 meV", "red")
]

ax1.set_ylim([0, 1.0])
ax2.set_ylim([0, 5.0])

ax1.set_xlim([0, 34.5])

xticks = np.arange(0, 35, 10)  
ax1.set_xticks(xticks)

fills = []
lines = []

# Plot data from files
for input_file, label, lc in files:
    # Load data from file
    data = np.loadtxt(input_file, comments="#")
    x = data[:, 0]  # meV
    vals = data[:, 1]  # ps1/meV scattering rates/phonon freq
    integral = data[:, 2]  # ps1/meV scattering rates/phonon freq

    line1, = ax1.plot(x, vals, linestyle='-', color=lc, linewidth=1.0, alpha=0.7)
    lines.append(line1)
    
    # Plot solid line for the right axis (dashed lines as in your corrected code) *4.1356
    line, = ax2.plot(x, integral, linestyle='--', color=lc, linewidth=1.0, alpha=0.7)
    #lines.append(line)

ax1.xaxis.set_minor_locator(AutoMinorLocator(2))  
ax1.yaxis.set_minor_locator(AutoMinorLocator(2))  
ax2.yaxis.set_minor_locator(AutoMinorLocator(2)) 

ax1.tick_params(which='minor', length=5, width=0.6)
ax2.tick_params(which='minor', length=5, width=0.6)

ax1.set_xlabel('$\\omega$ (meV)')
ax1.set_ylabel('$\\partial \\tau^{-1}(\\varepsilon_{\\rm F}) / \\partial \\omega$ (THz / meV)', color='black')
ax2.set_ylabel('$\\tau^{-1}(\\varepsilon_{\\rm F})$ (THz)', color='black')

fill_labels = [f"{label}" for _, label, _ in files]
line_labels = [f"{label}" for _, label, _ in files]

ax1.legend(lines, line_labels, loc='upper left', fontsize=9, ncol=1)


fig.tight_layout()

plt.savefig('Fig5_freq_tau.png', dpi=300, bbox_inches='tight')
plt.savefig('Fig5_freq_tau.pdf', format='pdf', bbox_inches='tight')

plt.show()