import matplotlib.pyplot as plt
import numpy as np
from matplotlib.ticker import AutoMinorLocator

plt.rcParams.update({
    'backend': 'TkAgg',
    'font.family': 'sans-serif',
    'font.sans-serif': ['DejaVu Sans', 'Helvetica', 'Bitstream Vera Sans', 'Arial', 'sans-serif'],
    'font.size': 10,
    'xtick.labelsize': 10,
    'ytick.labelsize': 10,
    'axes.linewidth': 0.8,
    'xtick.major.width': 1.0,
    'ytick.major.width': 1.0,
    'legend.columnspacing': 0.9,
    'legend.handletextpad': 0.25,
    'legend.borderaxespad': 0.25,
})

# Parameters from the gnuplot script
ymin = 0.0
ymax = 1.5
file1 = "nf_ndd.dat"
file2 = "nf_dd.dat"

x_positions = [0.0000, 0.9984, 1.2808, 1.5632, 2.4018, 2.9435, 4.2424]
x_labels = [r"$\Gamma$", r"$\Sigma$", "N", r"$\Sigma_1$", "Z", r"$\Gamma$", "X"]

fig, ax = plt.subplots(1, 1, figsize=(4.0, 2.8))

ax.set_xlim(0, 4.2424)
ax.set_ylim(ymin, ymax)
ax.set_yticks(np.arange(0, ymax+0.1, 0.5))
ax.set_ylabel(r'$\zeta_q$ (eV$^{-2}$)')

for x in x_positions:
    ax.axvline(x=x, color='black', linestyle='-', linewidth=0.2, alpha=0.5, zorder=0)

# Load and plot the data
try:
    data1 = np.loadtxt(file1, skiprows=1)
    data2 = np.loadtxt(file2, skiprows=1)
    
    # Plot with the scaling factor (185.096025) as in the original script
    ax.plot(data1[:, 0], data1[:, 2]/185.096025, 'k-', linewidth=1.0, alpha=0.7, label='w/o DDA')
    ax.plot(data2[:, 0], data2[:, 2]/185.096025, 'b--', linewidth=1.0, alpha=0.7, label='w   DDA')
except Exception as e:
    print(f"Error loading data files: {e}")

ax.xaxis.set_minor_locator(AutoMinorLocator(2))
ax.yaxis.set_minor_locator(AutoMinorLocator(2))

ax.set_xticks(x_positions)
ax.set_xticklabels(x_labels)
ax.legend(loc='upper left', frameon=False)

plt.tight_layout()

plt.savefig('FigS2_nest.png', dpi=300, bbox_inches='tight')
plt.savefig('FigS2_nest.pdf', dpi=300, bbox_inches='tight')

plt.show()