import numpy as np
import matplotlib.pyplot as plt
from matplotlib.gridspec import GridSpec
from matplotlib import ticker


# Set font parameters
plt.rcParams.update({
    'font.family': 'sans-serif',
    'font.sans-serif': ['DejaVu Sans', 'Helvetica', 'Bitstream Vera Sans', 'Arial', 'sans-serif'],
    'font.size': 10,  
    'xtick.labelsize': 10,
    'ytick.labelsize': 10,
    'axes.linewidth': 0.8,
    'xtick.major.width': 1.0,
    'ytick.major.width': 1.0,
    'legend.columnspacing': 0.5,
    'legend.handletextpad': 0.25,
    'legend.borderaxespad': 0.00,
})

# Define x-tick positions from Gnuplot script
x_ticks = [0.0000, 0.9984, 1.2808, 1.5632, 2.4018, 2.9435, 4.2424]
x_labels = [r'$\Gamma$', r'$\Sigma$' ,'N', r'$\Sigma_1$', 'Z', r'$\Gamma$', 'X']

fig = plt.figure(figsize=(7.5, 3.0))
gs = GridSpec(1, 2, width_ratios=[1, 1], wspace=0.12)

ax1 = fig.add_subplot(gs[0])  
ax2 = fig.add_subplot(gs[1])  

data_plus25 = np.loadtxt('scatd_25_new.dat')
data_minus25 = np.loadtxt('scatd_-25_new.dat')

x_plus25 = data_plus25[:, 0]
y_plus25 = data_plus25[:, 1]
z_plus25 = data_plus25[:, 2]

x_minus25 = data_minus25[:, 0]
y_minus25 = data_minus25[:, 1]
z_minus25 = data_minus25[:, 2]

scatter1 = ax1.scatter(x_minus25, y_minus25, c=z_minus25, cmap='coolwarm', 
                     vmin=-0.005, vmax=0.005, s=1, zorder=5)

scatter2 = ax2.scatter(x_plus25, y_plus25, c=z_plus25, cmap='coolwarm', 
                     vmin=-0.005, vmax=0.005, s=1, zorder=5)

for ax in [ax1, ax2]:
    for x_pos in x_ticks:
        ax.axvline(x=x_pos, color='black', linestyle='-', linewidth=0.2, alpha=0.5, zorder=0)
    
    ax.set_xlim(min(x_ticks), max(x_ticks))
    ax.set_ylim(0, 35)
    
    ax.set_xticks(x_ticks)
    ax.set_xticklabels(x_labels)
    
    ax.set_yticks(np.arange(0, 36, 10))
    
ax1.set_ylabel(r'$\omega$ (meV)')
ax1.text(-0.15, 0.94, '(a)', transform=ax1.transAxes, va='bottom', ha='left')
ax1.yaxis.set_minor_locator(ticker.AutoMinorLocator(2))
ax1.text(0.04, 0.03, r'$\gamma_{q\nu}^{-25} - \gamma_{q\nu}^0$', fontsize=8, transform=ax1.transAxes, va='bottom', ha='left')

ax2.text(-0.08, 0.94, '(b)', transform=ax2.transAxes, va='bottom', ha='left')
ax2.text(0.04, 0.03, r'$\gamma_{q\nu}^{+25} - \gamma_{q\nu}^0$', fontsize=8, transform=ax2.transAxes, va='bottom', ha='left')
ax2.set_ylabel('')
ax2.set_yticklabels([])
ax2.set_ylim(0, 35)  
ax2.yaxis.set_minor_locator(ticker.AutoMinorLocator(2))

cax = fig.add_axes([0.30, 0.90, 0.55, 0.02])  
cbar = fig.colorbar(scatter1, cax=cax, orientation='horizontal')
cbar.set_label(r'$\gamma_{q\nu}^{\pm 25} - \gamma_{q\nu}^0$ (meV)', labelpad=25, fontsize=8)
cbar.ax.xaxis.set_label_coords(-0.15, 0.45)  # Move label to left side
cbar.ax.xaxis.set_ticks_position('top')
cbar.ax.xaxis.set_label_position('top')
cbar.ax.tick_params(labelsize=8)  
cbar.ax.tick_params(pad=1)

plt.tight_layout(rect=[0, 0, 1, 0.92])  

plt.savefig('FigS4_gamma_doped.png', dpi=300, bbox_inches='tight')
plt.savefig('FigS4_gamma_doped.pdf', dpi=300, bbox_inches='tight')
plt.show()